==> tool-sql-2.6.0-pre3-sources.jar: io/ciera/tool/sql/architecture/type/Type.java <==
package io.ciera.tool.sql.architecture.type;


import io.ciera.runtime.summit.classes.IModelInstance;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.Sql;
import io.ciera.tool.sql.architecture.classes.InstSet;
import io.ciera.tool.sql.architecture.classes.ModelInst;
import io.ciera.tool.sql.architecture.file.File;
import io.ciera.tool.sql.architecture.type.BuiltInType;
import io.ciera.tool.sql.architecture.type.EnumeratedType;
import io.ciera.tool.sql.architecture.type.TypeReference;
import io.ciera.tool.sql.architecture.type.TypeReferenceSet;
import io.ciera.tool.sql.architecture.type.UnresolvedType;
import io.ciera.tool.sql.architecture.type.UserDefinedType;
import io.ciera.tool.sql.architecture.type.UserDefinedTypeSet;
import io.ciera.tool.sql.loader.GeneralLoader;
import io.ciera.tool.sql.loader.GeneralLoaderSet;
import io.ciera.tool.sql.loader.GeneralSerializer;
import io.ciera.tool.sql.loader.GeneralSerializerSet;
import io.ciera.tool.sql.ooaofooa.domain.DataType;

import types.ImportType;


public interface Type extends IModelInstance<Type,Sql> {

    // attributes
    public void setName( String m_name ) throws XtumlException;
    public String getName() throws XtumlException;
    public void setPackage( String m_package ) throws XtumlException;
    public String getPackage() throws XtumlException;
    public String getDefault_value() throws XtumlException;
    public void setDefault_value( String m_default_value ) throws XtumlException;
    public UniqueId getDT_ID() throws XtumlException;
    public void setDT_ID( UniqueId ref_DT_ID ) throws XtumlException;


    // operations
    public void addToImports( final File p_file,  final ImportType p_type ) throws XtumlException;
    public void dispose() throws XtumlException;
    public boolean primitive() throws XtumlException;
    public void resolve( final DataType p_s_dt ) throws XtumlException;


    // selections
    default public void addR3013_GeneralLoader( GeneralLoader inst ) {}
    default public void removeR3013_GeneralLoader( GeneralLoader inst ) {}
    public GeneralLoaderSet R3013_GeneralLoader() throws XtumlException;
    default public void addR3014_GeneralSerializer( GeneralSerializer inst ) {}
    default public void removeR3014_GeneralSerializer( GeneralSerializer inst ) {}
    public GeneralSerializerSet R3014_GeneralSerializer() throws XtumlException;
    default public void addR3800_referred_to_by_TypeReference( TypeReference inst ) {}
    default public void removeR3800_referred_to_by_TypeReference( TypeReference inst ) {}
    public TypeReferenceSet R3800_referred_to_by_TypeReference() throws XtumlException;
    default public void addR3802_used_as_base_for_UserDefinedType( UserDefinedType inst ) {}
    default public void removeR3802_used_as_base_for_UserDefinedType( UserDefinedType inst ) {}
    public UserDefinedTypeSet R3802_used_as_base_for_UserDefinedType() throws XtumlException;
    default public void setR407_is_a_BuiltInType( BuiltInType inst ) {}
    public BuiltInType R407_is_a_BuiltInType() throws XtumlException;
    default public void setR407_is_a_EnumeratedType( EnumeratedType inst ) {}
    public EnumeratedType R407_is_a_EnumeratedType() throws XtumlException;
    default public void setR407_is_a_InstSet( InstSet inst ) {}
    public InstSet R407_is_a_InstSet() throws XtumlException;
    default public void setR407_is_a_ModelInst( ModelInst inst ) {}
    public ModelInst R407_is_a_ModelInst() throws XtumlException;
    default public void setR407_is_a_UnresolvedType( UnresolvedType inst ) {}
    public UnresolvedType R407_is_a_UnresolvedType() throws XtumlException;
    default public void setR407_is_a_UserDefinedType( UserDefinedType inst ) {}
    public UserDefinedType R407_is_a_UserDefinedType() throws XtumlException;
    default public void setR423_is_basis_for_DataType( DataType inst ) {}
    public DataType R423_is_basis_for_DataType() throws XtumlException;


}

==> tool-sql-2.7.0-sources.jar: io/ciera/tool/sql/architecture/type/Type.java <==
package io.ciera.tool.sql.architecture.type;


import io.ciera.runtime.summit.classes.IModelInstance;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.tool.Sql;
import io.ciera.tool.sql.architecture.classes.InstSet;
import io.ciera.tool.sql.architecture.classes.ModelInst;
import io.ciera.tool.sql.architecture.file.File;
import io.ciera.tool.sql.architecture.type.BuiltInType;
import io.ciera.tool.sql.architecture.type.EnumeratedType;
import io.ciera.tool.sql.architecture.type.TypeReference;
import io.ciera.tool.sql.architecture.type.TypeReferenceSet;
import io.ciera.tool.sql.architecture.type.UnresolvedType;
import io.ciera.tool.sql.architecture.type.UserDefinedType;
import io.ciera.tool.sql.architecture.type.UserDefinedTypeSet;
import io.ciera.tool.sql.loader.GeneralLoader;
import io.ciera.tool.sql.loader.GeneralSerializer;
import io.ciera.tool.sql.ooaofooa.domain.DataType;

import types.ImportType;


public interface Type extends IModelInstance<Type,Sql> {

    // attributes
    public String getName() throws XtumlException;
    public void setName( String m_name ) throws XtumlException;
    public String getPackage() throws XtumlException;
    public void setPackage( String m_package ) throws XtumlException;
    public void setDefault_value( String m_default_value ) throws XtumlException;
    public String getDefault_value() throws XtumlException;


    // operations
    public void addToImports( final File p_file,  final ImportType p_type ) throws XtumlException;
    public void dispose() throws XtumlException;
    public boolean primitive() throws XtumlException;


    // selections
    default public void setR3013_GeneralLoader( GeneralLoader inst ) {}
    public GeneralLoader R3013_GeneralLoader() throws XtumlException;
    default public void setR3014_GeneralSerializer( GeneralSerializer inst ) {}
    public GeneralSerializer R3014_GeneralSerializer() throws XtumlException;
    default public void addR3800_referred_to_by_TypeReference( TypeReference inst ) {}
    default public void removeR3800_referred_to_by_TypeReference( TypeReference inst ) {}
    public TypeReferenceSet R3800_referred_to_by_TypeReference() throws XtumlException;
    default public void addR3802_used_as_base_for_UserDefinedType( UserDefinedType inst ) {}
    default public void removeR3802_used_as_base_for_UserDefinedType( UserDefinedType inst ) {}
    public UserDefinedTypeSet R3802_used_as_base_for_UserDefinedType() throws XtumlException;
    default public void setR407_is_a_BuiltInType( BuiltInType inst ) {}
    public BuiltInType R407_is_a_BuiltInType() throws XtumlException;
    default public void setR407_is_a_EnumeratedType( EnumeratedType inst ) {}
    public EnumeratedType R407_is_a_EnumeratedType() throws XtumlException;
    default public void setR407_is_a_InstSet( InstSet inst ) {}
    public InstSet R407_is_a_InstSet() throws XtumlException;
    default public void setR407_is_a_ModelInst( ModelInst inst ) {}
    public ModelInst R407_is_a_ModelInst() throws XtumlException;
    default public void setR407_is_a_UnresolvedType( UnresolvedType inst ) {}
    public UnresolvedType R407_is_a_UnresolvedType() throws XtumlException;
    default public void setR407_is_a_UserDefinedType( UserDefinedType inst ) {}
    public UserDefinedType R407_is_a_UserDefinedType() throws XtumlException;
    default public void setR423_DataType( DataType inst ) {}
    public DataType R423_DataType() throws XtumlException;


}
